<?php
/*
Plugin Name: GD Pages Navigator
Plugin URI: http://wp.gdragon.info/plugins/gd-pages-navigator/
Description: This widget can be used to change the way of navigating through your blog pages.
Version: 2.2.0
Author: Milan Petrovic
Author URI: http://wp.gdragon.info/

== Info ==

* change log is available in readme.txt
* to do list is available in readme.txt
* gdpnav_exclude_options: taken from flexi-pages-widget
  
== Copyright ==

Copyright 2008 Milan Petrovic (email : milan@gdragon.info)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/

require_once("gd-pages-functions.php");

class GDPagesNavigator
{
    var $default_options = array(
            'title'=>'Pages', 
            'autoTitle'=>1, 
            'blogRoot'=>1, 
            'emptyList'=>1, 
            'excludePages'=>'',
            'levelUp'=>0,
            'upLocTop'=>0,
            'upIdent'=>0,
            'renderType'=>1,
            'fhIdent'=>0,
            'identSize'=>5
        );
     
    function GDPagesNavigator() {
    }
    
    function init() {
        register_sidebar_widget(array('GD Pages Navigator', 'widgets'), array($this, 'widget'));
        register_widget_control(array('GD Pages Navigator', 'widgets'), array($this, 'control'), 250, 470);
    }
    
    function widget($args) {
        extract($args);
        global $post;

        $options = get_option('widget_gdpagesnavigator');
        $title = $options['title'];
        $renderType = $options['renderType'];
        $roodIdToRender = $post->post_parent;
        
        $levelTop = "";
        $levelBottom = "";
        $level = "";
        $ident = "";
        $debug = "";

        if ($renderType == "1") {
            if (!is_page()) {
                if ($options['blogRoot'] == 1)
                    $output = $this->render_level(0, 0, true);
                else return;
            }
            else {
                $exclude = isset($options['excludePages']) ? explode(',', $options['excludePages']) : array(); 
                if (in_array($post->ID, $exclude)) return;
                
                $parent_page = get_post($post->post_parent);
                $subpages = count(GDPages::get_subpages_ids($post->ID));
                
                if ($subpages > 0) {
                    $roodIdToRender = $post->ID;
                    if ($options['autoTitle'] == 1)
                        $title = $post->post_title;
                }
                
                if ($options['autoTitle'] == 1 && $subpages == 0) {
                    if ($post->post_parent == 0)
                        $title = $options['title'];
                    else
                        $title = $parent_page->post_title;
                }
                    
                if ($post->post_parent != 0) {
                    $level_page = $parent_page;
                    if ($options["levelUp"] == 1) {
                        $level = '<ul><li class="page_item page-item-'.$level_page->ID.'"><a href="'.get_page_link($level_page->ID).'" title='.attribute_escape(apply_filters('the_title', $level_page->post_title)).'>'.apply_filters('the_title', $level_page->post_title).'</a></li></ul>';
                        
                        if ($options["upLocTop"] == 0) 
                            $levelTop = $level;
                        else 
                            $levelBottom = $level;
                    }
                    if ($options["upIdent"] == 1) 
                        $ident = $options["identSize"];
                }
                
                $output = $this->render_level($roodIdToRender, $ident, true, true);
            }
        }
        if ($renderType == "2") {
            $output = $this->render_level(0, 0, true);
        }
        if ($renderType == "3") {
            $output = $this->render_level_hierarchy($options["fhIdent"] == 1 ? $options["identSize"] : 0);
        }
        
        if (!empty($output)) {
            echo $before_widget . $before_title . $title . $after_title;
            echo $levelTop . $output . $levelBottom . $after_widget; 
        }
    }
    
    function control() {
        $options = get_option('widget_gdpagesnavigator');
        if (!is_array($options)) {
            $options = $this->default_options;
        }
        
        if ($_POST['gdpnav-submit']) {
            $options['title'] = strip_tags(stripslashes($_POST['gdpnav-title']));
            $options['excludePages'] = isset($_REQUEST['gdpnav-excludePages']) ? implode(',', $_REQUEST['gdpnav-excludePages']) : ''; 
            $options['autoTitle'] = isset($_POST['gdpnav-autoTitle']);
            $options['blogRoot'] = isset($_POST['gdpnav-blogRoot']);
            $options['emptyList'] = isset($_POST['gdpnav-emptyList']);
            $options['levelUp'] = isset($_POST['gdpnav-levelUp']);
            $options['upLocTop'] = isset($_POST['gdpnav-upLocTop']);
            $options['upIdent'] = isset($_POST['gdpnav-upIdent']);
            $options['fhIdent'] = isset($_POST['gdpnav-fhIdent']);
            $options['renderType'] = $_POST['gdpnav-renderType'];
            if ($options['renderType'] == '1')
                $options['identSize'] = $_POST['gdpnav-identSize-1'];
            if ($options['renderType'] == '3')
                $options['identSize'] = $_POST['gdpnav-identSize-3'];
            update_option('widget_gdpagesnavigator', $options);
        }
        
        if (isset($options['autoTitle']))
            $autoTitle = $options['autoTitle'] ? 'checked="checked"' : '';

        if (isset($options['blogRoot']))
            $blogRoot = $options['blogRoot'] ? 'checked="checked"' : '';

        if (isset($options['emptyList']))
            $emptyList = $options['emptyList'] ? 'checked="checked"' : '';

        if (isset($options['levelUp']))
            $levelUp = $options['levelUp'] ? 'checked="checked"' : '';

        if (isset($options['upLocTop']))
            $upLocTop = $options['upLocTop'] ? 'checked="checked"' : '';

        if (isset($options['upIdent']))
            $upIdent = $options['upIdent'] ? 'checked="checked"' : '';

        if (isset($options['fhIdent']))
            $fhIdent = $options['fhIdent'] ? 'checked="checked"' : '';

        $title = htmlspecialchars($options['title'], ENT_QUOTES);
        $renderType = $options['renderType'];
        $identSize = $options['identSize'];
        
        for ($i = 1; $i < 4; $i++) {
            if ($i == $renderType)
                $render_method[$i] = ' selected="selected"';
            else
                $render_method[$i] = '';
        }
        
    ?>

        <script>
            function gdpnaChangeRender(index) {
                if (index == "1")
                {
                    document.getElementById("gdpnav-fieldset-1").style.display = "block"
                    document.getElementById("gdpnav-fieldset-2").style.display = "block"
                    document.getElementById("gdpnav-fieldset-3").style.display = "block"
                }
                else
                {
                    document.getElementById("gdpnav-fieldset-1").style.display = "none"
                    document.getElementById("gdpnav-fieldset-2").style.display = "none"
                    document.getElementById("gdpnav-fieldset-3").style.display = "none"
                }
                if (index == "3")
                    document.getElementById("gdpnav-fieldset-4").style.display = "block"
                else
                    document.getElementById("gdpnav-fieldset-4").style.display = "none"
            }
        </script>
        <fieldset style="border: 1px grey solid; padding: 6px">
        <legend>Title:</legend>
            <input class="widefat" style="width: 97%;" id="gdpnav-title" name="gdpnav-title" type="text" value="<?php echo $title; ?>" />
            <br /><label for="gdpnav-autoTitle" style="text-align:right;"><input class="checkbox" type="checkbox" <?php echo $autoTitle; ?> id="gdpnav-autoTitle" name="gdpnav-autoTitle" /> On subpages use parent name</label>
        </fieldset>

        <fieldset style="border: 1px grey solid; padding: 6px">
        <legend>Render Method:</legend>
            <select class="widefat" style="width: 100%;" name="gdpnav-renderType" id="gdpnav-renderType" onchange="gdpnaChangeRender(this.options[this.selectedIndex].value)">
                <option value="1"<?php echo $render_method[1]; ?>>Advanced Navigator</option>
                <option value="2"<?php echo $render_method[2]; ?>>Only Top Level Pages</option>
                <option value="3"<?php echo $render_method[3]; ?>>Full Pages Hierarchy</option>
            </select>
        </fieldset>

        <fieldset style="border: 1px grey solid; padding: 6px">
        <legend>Exclude Pages:</legend>
            <select class="widefat" style="width: 100%; height: 70px;" name="gdpnav-excludePages[]" id="gdpnav-excludePages" multiple="multiple"><?php $this->exclude_options("menu_order", "ASC", explode(',', $options['excludePages']),0,0) ?></select>
            <span style="font-size:80%">use shift or ctrl to select more then one page</span>
        </fieldset>
        
        <fieldset id="gdpnav-fieldset-1" style="border: 1px grey solid; padding: 6px; display: block;">
        <legend>Display top level Pages on:</legend>
            <label for="gdpnav-blogRoot" style="text-align:right;"><input class="checkbox" type="checkbox" <?php echo $blogRoot; ?> id="gdpnav-blogRoot" name="gdpnav-blogRoot" /> Non-pages</label>
        </fieldset>
        
        <fieldset id="gdpnav-fieldset-2" style="border: 1px grey solid; padding: 6px display: block;">
        <legend>Display parent level Pages on:</legend>
            <label for="gdpnav-emptyList" style="text-align:right;"><input class="checkbox" type="checkbox" <?php echo $emptyList; ?> id="gdpnav-emptyList" name="gdpnav-emptyList" /> Pages with no sub-pages</label>
        </fieldset>
        
        <fieldset id="gdpnav-fieldset-3" style="border: 1px grey solid; padding: 6px display: block;">
        <legend>Additional level up item:</legend>
            <label for="gdpnav-levelUp" style="text-align:right;"><input class="checkbox" type="checkbox" <?php echo $levelUp; ?> id="gdpnav-levelUp" name="gdpnav-levelUp" /> Display on sub-pages level</label>
            <br />
            <div style="padding-left:20px">
                <label for="gdpnav-upLocTop" style="text-align:right;"><input class="checkbox" type="checkbox" <?php echo $upLocTop; ?> id="gdpnav-upLocTop" name="gdpnav-upLocTop" /> Go Level up item on bottom</label>
                <br />
                <label for="gdpnav-upIdent" style="text-align:right;"><input class="checkbox" type="checkbox" <?php echo $upIdent; ?> id="gdpnav-upIdent" name="gdpnav-upIdent" /> Display items idented</label>
            </div>
            Aditional Identation: <input class="widefat" style="text-align: right; width: 65px" name="gdpnav-identSize-1" id="gdpnav-identSize-1" type="text" value="<?php echo $identSize; ?>" /> [px]
        </fieldset>

        <fieldset id="gdpnav-fieldset-4" style="border: 1px grey solid; padding: 6px display: none;">
        <legend>Full hierarchy:</legend>
            <label for="gdpnav-fhIdent" style="text-align:right;"><input class="checkbox" type="checkbox" <?php echo $fhIdent; ?> id="gdpnav-fhIdent" name="gdpnav-fhIdent" /> Display items idented</label>
            <br />
            Aditional Identation: <input class="widefat" style="text-align: right; width: 65px" name="gdpnav-identSize-3" id="gdpnav-identSize-3" type="text" value="<?php echo $identSize; ?>" /> [px]
        </fieldset>

        <br />
        <input type="hidden" id="gdpnav-submit" name="gdpnav-submit" value="1" />
        <script>
            gdpnaChangeRender(<?php echo $renderType; ?>);
        </script>

    <?php

    }

    function render_level_hierarchy($ident = 0) {
        return $this->render_level(0, $ident);
    }
    
    function render_level($rootId = 0, $ident = 0, $top = false, $render_ident = false) {
        $items =  GDPages::get_pages($rootId);
        
        if ($render_ident)
            $result = '<ul style="padding-left:'.$ident.'px">';
        else
            $result = '<ul>';
        for ($i = 0; $i < count($items); $i++) {
            $result .= '<li class="page_item page-item-'.$items[$i]["id"].'"><a title="'.attribute_escape(apply_filters('the_title', $items[$i]["title"])).'" href="'.get_page_link($items[$i]["id"]).'">'.attribute_escape(apply_filters('the_title', $items[$i]["title"])).'</a>';
            if ($items[$i]["subpages"] > 0 && !$top) {
                if ($render_ident)
                    $ident += $ident;
                $result .= $this->render_level($items[$i]["id"], $ident, false, true);
            }
            $result .= '</li>';
        }
        $result .= '</ul>';
        return $result;
    }

    function exclude_options($sort_column = "menu_order", $sort_order = "ASC", $selected = array(), $parent = 0, $level = 0) {
        global $wpdb;
        $items = $wpdb->get_results( "SELECT ID, post_parent, post_title FROM $wpdb->posts WHERE post_parent = $parent AND post_type = 'page' AND post_status = 'publish' ORDER BY {$sort_column} {$sort_order}" );

        if ( $items ) {
            foreach ( $items as $item ) {
                $pad = str_repeat( '&nbsp;', $level * 3 );
                if ( in_array($item->ID, $selected))
                    $current = ' selected="selected"';
                else
                    $current = '';
    
                echo "\n\t<option value='$item->ID'$current>$pad $item->post_title</option>";
                $this->exclude_options( $sort_column, $sort_order, $selected, $item->ID,  $level +1 );
            }
        } 
        else {
            return false;
        }
    }
}

$gdpg = new GDPagesNavigator();
add_action('plugins_loaded', array($gdpg, 'init'));

?>